#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<name>|<state>|<status>
<<<hpe_oneview_server_hardware:sep(124)>>>
Frame3-unten-CZ3715W1XP, bay 2|ProfileApplied|OK
Frame1-oben-CZJ7170S95, bay 4|ProfileApplied|OK
Frame1-oben-CZJ7170S95, bay 3|ProfileApplied|OK
"""

from .agent_based_api.v1 import *

info_list = ["name", "serverName", "state", "status"]
state_map = {
    0: State.OK,
    1: State.WARN,
    2: State.CRIT,
    3: State.UNKNOWN
}

def parse_hpe_oneview_server_hardware(string_table):
    output = []
    for hardware in string_table:
        info_map = dict(zip(info_list, hardware))
        output.append(info_map)
    return output

register.agent_section(
    name="hpe_oneview_server_hardware",
    parse_function=parse_hpe_oneview_server_hardware
)

def discovery_hpe_oneview_server_hardware(section):
    for hardware in section:
        if len(hardware["serverName"]) != 0:
            yield Service(item=hardware["serverName"])
        else:
            yield Service(item=hardware["name"])


def check_hpe_oneview_server_hardware(item, params, section):
    map_status = params["map_status"]
    map_state = params["map_state"]

    for hardware in section:
        if hardware["serverName"] == item or hardware["name"] == item:

            s= state_map[map_status[hardware["status"]]]
            
            yield Result(state=s, summary="Status: {}".format(hardware["status"]))

            s= state_map[map_state[hardware["state"]]]

            yield Result(state=s, summary="State: {}".format(hardware["state"]))



register.check_plugin(
    name="hpe_oneview_server_hardware",
    service_name="Server Hardware %s",
    check_ruleset_name="hpe_oneview_server_hardware",
    check_default_parameters={
        "map_status": {
            "OK": 0,
            "Disabled": 1,
            "Warning": 1,
            "Critical": 2,
            "Unknown": 3
            },
        "map_state": {
            "Monitored": 0,
            "NoProfileApplied": 0,
            "Adding": 0,
            "Unknown": 3,
            "Unmanaged": 1,
            "Removing": 1,
            "RemoveFailed": 2,
            "Removed": 1,
            "ApplyingProfile": 0,
            "ProfileApplied": 0,
            "RemovingProfile": 1,
            "ProfileError": 2,
            "Unsupported": 2,
            "UpdatingFirmware": 0,
            }
        },
    discovery_function=discovery_hpe_oneview_server_hardware,
    check_function=check_hpe_oneview_server_hardware,
)
