#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2020  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
    MonitoringState
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersApplications,
)


def _parameter_valuespec_hpe_oneview_appliance_state():
    return Dictionary(elements=[
        ("map_status",
         Dictionary(
             title=_("Map Attribute 'Status'"),
             elements=[
                 ("OK", MonitoringState(title=_("OK"), default_value=0)),
                 ("CONFIGURATION_ERROR", MonitoringState(title=_("CONFIGURATION_ERROR"), default_value=2)),
                 ("ERROR", MonitoringState(title=_("ERROR"), default_value=2)),
                 ("FACTORY_RESET", MonitoringState(title=_("FACTORY_RESET"), default_value=1)),
                 ("FAILOVER", MonitoringState(title=_("FAILOVER"), default_value=1)),
                 ("INCOMPATIBLE_MODEL_ERROR", MonitoringState(title=_("INCOMPATIBLE_MODEL_ERROR"), default_value=2)),
                 ("NETWORK_ERROR", MonitoringState(title=_("NETWORK_ERROR"), default_value=2)),
                 ("RESTORE", MonitoringState(title=_("RESTORE"), default_value=1)),
                 ("RESTORE_NO_RESET_ERROR", MonitoringState(title=_("RESTORE_NO_RESET_ERROR"), default_value=2)),
                 ("STARTING", MonitoringState(title=_("STARTING"), default_value=0)),
                 ("STOPPED", MonitoringState(title=_("STOPPED"), default_value=2)),
                 ("UPGRADE", MonitoringState(title=_("UPGRADE"), default_value=0)),

             ],
             optional_keys=False,
         )),
    ],)

rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="hpe_oneview_appliance_state",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_hpe_oneview_appliance_state,
        title=lambda: _("HPE OneView Appliance States"),
    ))
